@@ -1,6 +1,7 @@
 
 
-gjamPredict <- function(output, newdata = NULL, y2plot = NULL, ylim=NULL){
+gjamPredict <- function(output, newdata = NULL, y2plot = NULL, ylim=NULL,
+                        FULL = FALSE){
   
   # output   - gjamGibbs object
   # newdata  - list with xdata and y needed for prediction
@@ -10,6 +11,6 @@ gjamPredict <- function(output, newdata = NULL, y2plot = NULL, ylim=NULL){
   PLOT <- T
   if(is.null(y2plot))PLOT <- F
   
-  invisible( .gjamPrediction( output, newdata, y2plot, PLOT, ylim ) )
+  invisible( .gjamPrediction( output, newdata, y2plot, PLOT, ylim, FULL ) )
   
 }
